diff -ru --new-file tcptraceroute-1.4.orig/Makefile tcptraceroute-1.4/Makefile
--- tcptraceroute-1.4.orig/Makefile	Mon May 20 11:11:38 2002
+++ tcptraceroute-1.4/Makefile	Thu Jan  1 10:00:00 1970
@@ -1,33 +0,0 @@
-# vim:set ts=4 sw=4 ai:
-
-# tcptraceroute -- A traceroute implementation using TCP packets
-# Copyright (c) 2001, 2002 Michael C. Toren <mct@toren.net>
-
-CC = gcc
-CFLAGS = -O2 -Wall
-DESTDIR=/usr/local/bin
-
-tcptraceroute: tcptraceroute.c
-	$(CC) $(CFLAGS) `libnet-config --defines` \
-		-o tcptraceroute tcptraceroute.c \
-		`libnet-config --libs` -lpcap
-
-static:
-	$(MAKE) tcptraceroute CFLAGS="$(CFLAGS) -static"
-
-install: tcptraceroute
-	install -D tcptraceroute $(DESTDIR)/tcptraceroute
-
-distrib: clean changelog man
-
-changelog: tcptraceroute.c Makefile
-	perl -000 -ne 'next unless (/\*\s+Revision\s+history:/); \
-		print "Extracted from tcptraceroute.c:\n\n$$_"; exit;' \
-		< tcptraceroute.c | expand -t 4 > changelog
-
-man: tcptraceroute.8.html Makefile
-tcptraceroute.8.html: tcptraceroute.8
-	rman -fHTML -r- tcptraceroute.8 > tcptraceroute.8.html
-
-clean:
-	rm -f core a.out tcptraceroute *~
diff -ru --new-file tcptraceroute-1.4.orig/Makefile.in tcptraceroute-1.4/Makefile.in
--- tcptraceroute-1.4.orig/Makefile.in	Thu Jan  1 10:00:00 1970
+++ tcptraceroute-1.4/Makefile.in	Wed Aug 14 18:18:55 2002
@@ -0,0 +1,47 @@
+# vim:set ts=4 sw=4 ai:
+
+# tcptraceroute -- A traceroute implementation using TCP packets
+# Copyright (c) 2001, 2002 Michael C. Toren <mct@toren.net>
+
+CC = @CC@
+CFLAGS = @CFLAGS@
+LIBS=@LIBS@
+INSTALL=@INSTALL@
+
+prefix=@prefix@
+bindir=$(prefix)/bin
+mandir=$(prefix)/man
+
+tcptraceroute: tcptraceroute.c
+	$(CC) $(CFLAGS) -o tcptraceroute tcptraceroute.c $(LIBS)
+
+static:
+	$(MAKE) tcptraceroute CFLAGS="$(CFLAGS) -static"
+
+install: tcptraceroute
+	$(INSTALL) -D tcptraceroute $(bindir)/tcptraceroute
+	$(INSTALL) -D tcptraceroute.8 $(mandir)/tcptraceroute.8
+
+distrib: clean changelog man
+
+changelog: tcptraceroute.c Makefile
+	perl -000 -ne 'next unless (/\*\s+Revision\s+history:/); \
+		print "Extracted from tcptraceroute.c:\n\n$$_"; exit;' \
+		< tcptraceroute.c | expand -t 4 > changelog
+
+man: tcptraceroute.8.html Makefile
+tcptraceroute.8.html: tcptraceroute.8
+	rman -fHTML -r- tcptraceroute.8 > tcptraceroute.8.html
+
+distprep:	distclean
+	autoreconf
+
+clean:
+	rm -f core a.out tcptraceroute *~
+
+distclean:	clean
+	rm -f Makefile config.h config.status config.log *~
+	rm -rf autom4te.cache
+
+veryclean:	distclean
+	rm -f config.h.in configure
diff -ru --new-file tcptraceroute-1.4.orig/configure.ac tcptraceroute-1.4/configure.ac
--- tcptraceroute-1.4.orig/configure.ac	Thu Jan  1 10:00:00 1970
+++ tcptraceroute-1.4/configure.ac	Wed Aug 14 17:42:58 2002
@@ -0,0 +1,38 @@
+# Process this file with autoconf to produce a configure script.
+AC_INIT(tcptraceroute, 1.4, tcptraceroute-dev@netisland.net)
+AC_CONFIG_SRCDIR([tcptraceroute.c])
+AC_CONFIG_HEADER([config.h])
+
+# Checks for programs.
+AC_PROG_CC
+AC_PROG_INSTALL
+AC_CHECK_PROG([libnetconf], [libnet-config], yes)
+
+if test "$libnetconf" == yes
+then
+	LIBS="$LIBS `libnet-config --libs`"
+	CFLAGS="$CFLAGS `libnet-config --defines`"
+else
+	AC_MSG_ERROR([*** libnet-config not found ***])
+fi
+
+# Checks for libraries.
+AC_CHECK_LIB([socket], [gethostbyname], LIBS="$LIBS -lsocket")
+AC_CHECK_LIB([pcap], [pcap_major_version], LIBS="$LIBS -lpcap" ,AC_MSG_ERROR([*** libpcap not found ***]))
+
+# Checks for header files.
+AC_HEADER_STDC
+AC_CHECK_HEADERS([arpa/inet.h fcntl.h netdb.h netinet/in.h stdlib.h string.h sys/ioctl.h sys/socket.h unistd.h])
+
+# Checks for typedefs, structures, and compiler characteristics.
+AC_C_CONST
+AC_HEADER_TIME
+
+# Checks for library functions.
+AC_PROG_GCC_TRADITIONAL
+AC_FUNC_MALLOC
+AC_FUNC_VPRINTF
+AC_CHECK_FUNCS([gettimeofday memset select socket strchr])
+
+AC_CONFIG_FILES([Makefile])
+AC_OUTPUT
diff -ru --new-file tcptraceroute-1.4.orig/install-sh tcptraceroute-1.4/install-sh
--- tcptraceroute-1.4.orig/install-sh	Thu Jan  1 10:00:00 1970
+++ tcptraceroute-1.4/install-sh	Wed Aug 14 16:21:04 2002
@@ -0,0 +1,251 @@
+#!/bin/sh
+#
+# install - install a program, script, or datafile
+# This comes from X11R5 (mit/util/scripts/install.sh).
+#
+# Copyright 1991 by the Massachusetts Institute of Technology
+#
+# Permission to use, copy, modify, distribute, and sell this software and its
+# documentation for any purpose is hereby granted without fee, provided that
+# the above copyright notice appear in all copies and that both that
+# copyright notice and this permission notice appear in supporting
+# documentation, and that the name of M.I.T. not be used in advertising or
+# publicity pertaining to distribution of the software without specific,
+# written prior permission.  M.I.T. makes no representations about the
+# suitability of this software for any purpose.  It is provided "as is"
+# without express or implied warranty.
+#
+# Calling this script install-sh is preferred over install.sh, to prevent
+# `make' implicit rules from creating a file called install from it
+# when there is no Makefile.
+#
+# This script is compatible with the BSD install script, but was written
+# from scratch.  It can only install one file at a time, a restriction
+# shared with many OS's install programs.
+
+
+# set DOITPROG to echo to test this script
+
+# Don't use :- since 4.3BSD and earlier shells don't like it.
+doit="${DOITPROG-}"
+
+
+# put in absolute paths if you don't have them in your path; or use env. vars.
+
+mvprog="${MVPROG-mv}"
+cpprog="${CPPROG-cp}"
+chmodprog="${CHMODPROG-chmod}"
+chownprog="${CHOWNPROG-chown}"
+chgrpprog="${CHGRPPROG-chgrp}"
+stripprog="${STRIPPROG-strip}"
+rmprog="${RMPROG-rm}"
+mkdirprog="${MKDIRPROG-mkdir}"
+
+transformbasename=""
+transform_arg=""
+instcmd="$mvprog"
+chmodcmd="$chmodprog 0755"
+chowncmd=""
+chgrpcmd=""
+stripcmd=""
+rmcmd="$rmprog -f"
+mvcmd="$mvprog"
+src=""
+dst=""
+dir_arg=""
+
+while [ x"$1" != x ]; do
+    case $1 in
+	-c) instcmd="$cpprog"
+	    shift
+	    continue;;
+
+	-d) dir_arg=true
+	    shift
+	    continue;;
+
+	-m) chmodcmd="$chmodprog $2"
+	    shift
+	    shift
+	    continue;;
+
+	-o) chowncmd="$chownprog $2"
+	    shift
+	    shift
+	    continue;;
+
+	-g) chgrpcmd="$chgrpprog $2"
+	    shift
+	    shift
+	    continue;;
+
+	-s) stripcmd="$stripprog"
+	    shift
+	    continue;;
+
+	-t=*) transformarg=`echo $1 | sed 's/-t=//'`
+	    shift
+	    continue;;
+
+	-b=*) transformbasename=`echo $1 | sed 's/-b=//'`
+	    shift
+	    continue;;
+
+	*)  if [ x"$src" = x ]
+	    then
+		src=$1
+	    else
+		# this colon is to work around a 386BSD /bin/sh bug
+		:
+		dst=$1
+	    fi
+	    shift
+	    continue;;
+    esac
+done
+
+if [ x"$src" = x ]
+then
+	echo "install:	no input file specified"
+	exit 1
+else
+	:
+fi
+
+if [ x"$dir_arg" != x ]; then
+	dst=$src
+	src=""
+	
+	if [ -d $dst ]; then
+		instcmd=:
+		chmodcmd=""
+	else
+		instcmd=$mkdirprog
+	fi
+else
+
+# Waiting for this to be detected by the "$instcmd $src $dsttmp" command
+# might cause directories to be created, which would be especially bad 
+# if $src (and thus $dsttmp) contains '*'.
+
+	if [ -f $src -o -d $src ]
+	then
+		:
+	else
+		echo "install:  $src does not exist"
+		exit 1
+	fi
+	
+	if [ x"$dst" = x ]
+	then
+		echo "install:	no destination specified"
+		exit 1
+	else
+		:
+	fi
+
+# If destination is a directory, append the input filename; if your system
+# does not like double slashes in filenames, you may need to add some logic
+
+	if [ -d $dst ]
+	then
+		dst="$dst"/`basename $src`
+	else
+		:
+	fi
+fi
+
+## this sed command emulates the dirname command
+dstdir=`echo $dst | sed -e 's,[^/]*$,,;s,/$,,;s,^$,.,'`
+
+# Make sure that the destination directory exists.
+#  this part is taken from Noah Friedman's mkinstalldirs script
+
+# Skip lots of stat calls in the usual case.
+if [ ! -d "$dstdir" ]; then
+defaultIFS='
+	'
+IFS="${IFS-${defaultIFS}}"
+
+oIFS="${IFS}"
+# Some sh's can't handle IFS=/ for some reason.
+IFS='%'
+set - `echo ${dstdir} | sed -e 's@/@%@g' -e 's@^%@/@'`
+IFS="${oIFS}"
+
+pathcomp=''
+
+while [ $# -ne 0 ] ; do
+	pathcomp="${pathcomp}${1}"
+	shift
+
+	if [ ! -d "${pathcomp}" ] ;
+        then
+		$mkdirprog "${pathcomp}"
+	else
+		:
+	fi
+
+	pathcomp="${pathcomp}/"
+done
+fi
+
+if [ x"$dir_arg" != x ]
+then
+	$doit $instcmd $dst &&
+
+	if [ x"$chowncmd" != x ]; then $doit $chowncmd $dst; else : ; fi &&
+	if [ x"$chgrpcmd" != x ]; then $doit $chgrpcmd $dst; else : ; fi &&
+	if [ x"$stripcmd" != x ]; then $doit $stripcmd $dst; else : ; fi &&
+	if [ x"$chmodcmd" != x ]; then $doit $chmodcmd $dst; else : ; fi
+else
+
+# If we're going to rename the final executable, determine the name now.
+
+	if [ x"$transformarg" = x ] 
+	then
+		dstfile=`basename $dst`
+	else
+		dstfile=`basename $dst $transformbasename | 
+			sed $transformarg`$transformbasename
+	fi
+
+# don't allow the sed command to completely eliminate the filename
+
+	if [ x"$dstfile" = x ] 
+	then
+		dstfile=`basename $dst`
+	else
+		:
+	fi
+
+# Make a temp file name in the proper directory.
+
+	dsttmp=$dstdir/#inst.$$#
+
+# Move or copy the file name to the temp name
+
+	$doit $instcmd $src $dsttmp &&
+
+	trap "rm -f ${dsttmp}" 0 &&
+
+# and set any options; do chmod last to preserve setuid bits
+
+# If any of these fail, we abort the whole thing.  If we want to
+# ignore errors from any of these, just make sure not to ignore
+# errors from the above "$doit $instcmd $src $dsttmp" command.
+
+	if [ x"$chowncmd" != x ]; then $doit $chowncmd $dsttmp; else :;fi &&
+	if [ x"$chgrpcmd" != x ]; then $doit $chgrpcmd $dsttmp; else :;fi &&
+	if [ x"$stripcmd" != x ]; then $doit $stripcmd $dsttmp; else :;fi &&
+	if [ x"$chmodcmd" != x ]; then $doit $chmodcmd $dsttmp; else :;fi &&
+
+# Now rename the file to the real destination.
+
+	$doit $rmcmd -f $dstdir/$dstfile &&
+	$doit $mvcmd $dsttmp $dstdir/$dstfile 
+
+fi &&
+
+
+exit 0
diff -ru --new-file tcptraceroute-1.4.orig/tcptraceroute.c tcptraceroute-1.4/tcptraceroute.c
--- tcptraceroute-1.4.orig/tcptraceroute.c	Wed Jul 31 07:51:27 2002
+++ tcptraceroute-1.4/tcptraceroute.c	Wed Aug 14 18:04:34 2002
@@ -30,7 +30,9 @@
  * Updates are available from http://michael.toren.net/code/tcptraceroute/
  */
 
-#define VERSION "tcptraceroute 1.4 (2002-07-30)"
+#include "config.h"
+
+#define VERSION PACKAGE_STRING" (2002-07-30)"
 #define BANNER  "Copyright (c) 2001, 2002 Michael C. Toren <mct@toren.net>\n\
 Updates are available from http://michael.toren.net/code/tcptraceroute/\n"
 
